dm: blk: Rename get_device_and_partition()
authorSimon Glass <sjg@chromium.org>
Mon, 29 Feb 2016 22:25:44 +0000 (15:25 -0700)
committerSimon Glass <sjg@chromium.org>
Mon, 14 Mar 2016 21:34:50 +0000 (15:34 -0600)
Rename this function to blk_get_device_part_str(). This is a better name
because it makes it clear that the function returns a block device and
parses a string.

Signed-off-by: Simon Glass <sjg@chromium.org>
Reviewed-by: Bin Meng <bmeng.cn@gmail.com>
Tested-by: Stephen Warren <swarren@nvidia.com>
cmd/disk.c
cmd/fat.c
cmd/part.c
cmd/reiser.c
cmd/zfs.c
common/env_fat.c
disk/part.c
fs/fs.c
fs/ubifs/ubifs.c
include/part.h

index c53c2a2dbfeac9aad6509e77452bb3a91bef9cc1..0883c79506cd44adad9cef839a5b1f58977b88a1 100644 (file)
@@ -38,7 +38,7 @@ int common_diskboot(cmd_tbl_t *cmdtp, const char *intf, int argc,
 
        bootstage_mark(BOOTSTAGE_ID_IDE_BOOT_DEVICE);
 
-       part = get_device_and_partition(intf, (argc == 3) ? argv[2] : NULL,
+       part = blk_get_device_part_str(intf, (argc == 3) ? argv[2] : NULL,
                                        &dev_desc, &info, 1);
        if (part < 0) {
                bootstage_error(BOOTSTAGE_ID_IDE_TYPE);
index 82b9b38c2c56f9bd3b4e49010f24c9b968b65eb4..18a1be97e0a4ded538e9efbb0cd04d315b39aa5d 100644 (file)
--- a/cmd/fat.c
+++ b/cmd/fat.c
@@ -77,7 +77,7 @@ static int do_fat_fsinfo(cmd_tbl_t *cmdtp, int flag, int argc,
                return 0;
        }
 
-       part = get_device_and_partition(argv[1], argv[2], &dev_desc, &info, 1);
+       part = blk_get_device_part_str(argv[1], argv[2], &dev_desc, &info, 1);
        if (part < 0)
                return 1;
 
@@ -114,7 +114,7 @@ static int do_fat_fswrite(cmd_tbl_t *cmdtp, int flag,
        if (argc < 5)
                return cmd_usage(cmdtp);
 
-       part = get_device_and_partition(argv[1], argv[2], &dev_desc, &info, 1);
+       part = blk_get_device_part_str(argv[1], argv[2], &dev_desc, &info, 1);
        if (part < 0)
                return 1;
 
index dd32d505b0bfe1a1dfe008ecdf79a129b2617d88..415b38a5227684c3a6b2d7185a61681970061b1e 100644 (file)
@@ -37,7 +37,7 @@ static int do_part_uuid(int argc, char * const argv[])
        if (argc > 3)
                return CMD_RET_USAGE;
 
-       part = get_device_and_partition(argv[0], argv[1], &dev_desc, &info, 0);
+       part = blk_get_device_part_str(argv[0], argv[1], &dev_desc, &info, 0);
        if (part < 0)
                return 1;
 
index 1cca5eb6581bcc830f20fa06f7f047aa565525ef..a7179561e4a7fe144adb4f0ee640c42bcd372703 100644 (file)
@@ -40,7 +40,7 @@ int do_reiserls (cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        if (argc < 3)
                return CMD_RET_USAGE;
 
-       part = get_device_and_partition(argv[1], argv[2], &dev_desc, &info, 1);
+       part = blk_get_device_part_str(argv[1], argv[2], &dev_desc, &info, 1);
        if (part < 0)
                return 1;
 
@@ -122,7 +122,7 @@ int do_reiserload (cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
                return 1;
        }
 
-       part = get_device_and_partition(argv[1], argv[2], &dev_desc, &info, 1);
+       part = blk_get_device_part_str(argv[1], argv[2], &dev_desc, &info, 1);
        if (part < 0)
                return 1;
 
index 9076a8a6bbd81f592fa7ab5ad8b11bba164c2a37..bb61afd80decf2aa26e9eff12745be538088c3de 100644 (file)
--- a/cmd/zfs.c
+++ b/cmd/zfs.c
@@ -80,7 +80,7 @@ static int do_zfs_load(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[]
                return 1;
        }
 
-       part = get_device_and_partition(argv[1], argv[2], &dev_desc, &info, 1);
+       part = blk_get_device_part_str(argv[1], argv[2], &dev_desc, &info, 1);
        if (part < 0)
                return 1;
 
@@ -145,7 +145,7 @@ static int do_zfs_ls(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        if (argc == 4)
                filename = argv[3];
 
-       part = get_device_and_partition(argv[1], argv[2], &dev_desc, &info, 1);
+       part = blk_get_device_part_str(argv[1], argv[2], &dev_desc, &info, 1);
        if (part < 0)
                return 1;
 
index e88279eb705b79f6cd1fddcde409a5727d909ee5..2f2271035557edf41db89647fdd0aee21ac7d4f8 100644 (file)
@@ -48,7 +48,7 @@ int saveenv(void)
        if (err)
                return err;
 
-       part = get_device_and_partition(FAT_ENV_INTERFACE,
+       part = blk_get_device_part_str(FAT_ENV_INTERFACE,
                                        FAT_ENV_DEVICE_AND_PART,
                                        &dev_desc, &info, 1);
        if (part < 0)
@@ -82,7 +82,7 @@ void env_relocate_spec(void)
        int dev, part;
        int err;
 
-       part = get_device_and_partition(FAT_ENV_INTERFACE,
+       part = blk_get_device_part_str(FAT_ENV_INTERFACE,
                                        FAT_ENV_DEVICE_AND_PART,
                                        &dev_desc, &info, 1);
        if (part < 0)
index 2e7adbcd9db98963cc2af294395f8548f5d80b09..255ee7959f3e79255dd7478e305b17f3fa2a3c8e 100644 (file)
@@ -511,7 +511,7 @@ cleanup:
 #define PART_UNSPECIFIED -2
 #define PART_AUTO -1
 #define MAX_SEARCH_PARTITIONS 16
-int get_device_and_partition(const char *ifname, const char *dev_part_str,
+int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
                             struct blk_desc **dev_desc,
                             disk_partition_t *info, int allow_whole_dev)
 {
diff --git a/fs/fs.c b/fs/fs.c
index 8515beabf51bc712b6d2fe56ba2e41b5e4b9afc5..595ff1fe69b5bc446ebd32c3d7badd7726348d63 100644 (file)
--- a/fs/fs.c
+++ b/fs/fs.c
@@ -213,7 +213,7 @@ int fs_set_blk_dev(const char *ifname, const char *dev_part_str, int fstype)
        }
 #endif
 
-       part = get_device_and_partition(ifname, dev_part_str, &fs_dev_desc,
+       part = blk_get_device_part_str(ifname, dev_part_str, &fs_dev_desc,
                                        &fs_partition, 1);
        if (part < 0)
                return -1;
index 168ae2b697b0d8ee6277a53dfd9cc1bc3512ae0f..cdc04c662dd8d9c358c344b8a7e02e83bc5effad 100644 (file)
@@ -569,7 +569,7 @@ int ubifs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
        }
 
        /*
* Should never happen since get_device_and_partition() already checks
         * this, but better safe then sorry.
         */
        if (!ubifs_is_mounted()) {
index 6ca87d0f6317ac250fb893f97a61e964192eefcb..6197101a96963d2c1925af4a50f8a27132f86c94 100644 (file)
@@ -129,9 +129,43 @@ void dev_print(struct blk_desc *dev_desc);
  */
 int blk_get_device_by_str(const char *ifname, const char *dev_str,
                          struct blk_desc **dev_desc);
-int get_device_and_partition(const char *ifname, const char *dev_part_str,
-                            struct blk_desc **dev_desc,
-                            disk_partition_t *info, int allow_whole_dev);
+
+/**
+ * blk_get_device_part_str() - Get a block device and partition
+ *
+ * This calls blk_get_device_by_str() to look up a device. It also looks up
+ * a partition and returns information about it.
+ *
+ * @dev_part_str is in the format:
+ *     <dev>.<hw_part>:<part> where <dev> is the device number,
+ *     <hw_part> is the optional hardware partition number and
+ *     <part> is the partition number
+ *
+ * If ifname is "hostfs" then this function returns the sandbox host block
+ * device.
+ *
+ * If ifname is ubi, then this function returns 0, with @info set to a
+ * special UBI device.
+ *
+ * If @dev_part_str is NULL or empty or "-", then this function looks up
+ * the "bootdevice" environment variable and uses that string instead.
+ *
+ * If the partition string is empty then the first partition is used. If the
+ * partition string is "auto" then the first bootable partition is used.
+ *
+ * @ifname:    Interface name (e.g. "ide", "scsi")
+ * @dev_part_str:      Device and partition string
+ * @dev_desc:  Returns a pointer to the block device on success
+ * @info:      Returns partition information
+ * @allow_whole_dev:   true to allow the user to select partition 0
+ *             (which means the whole device), false to require a valid
+ *             partition number >= 1
+ * @return partition number, or -1 on error
+ *
+ */
+int blk_get_device_part_str(const char *ifname, const char *dev_part_str,
+                           struct blk_desc **dev_desc,
+                           disk_partition_t *info, int allow_whole_dev);
 #else
 static inline struct blk_desc *blk_get_dev(const char *ifname, int dev)
 { return NULL; }
@@ -153,7 +187,7 @@ static inline void dev_print(struct blk_desc *dev_desc) {}
 static inline int blk_get_device_by_str(const char *ifname, const char *dev_str,
                                        struct blk_desc **dev_desc)
 { return -1; }
-static inline int get_device_and_partition(const char *ifname,
+static inline int blk_get_device_part_str(const char *ifname,
                                           const char *dev_part_str,
                                           struct blk_desc **dev_desc,
                                           disk_partition_t *info,
@@ -569,7 +569,7 @@ int ubifs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
 
        /*
-        * Should never happen since get_device_and_partition() already checks
+        * Should never happen since blk_get_device_part_str() already checks
         * this, but better safe then sorry.
         */